pub fn http_client_builder() -> ClientBuilderExpand description
Return a reqwest client builder after installing the Rustls ring provider once.
pub fn http_client_builder() -> ClientBuilderReturn a reqwest client builder after installing the Rustls ring provider once.