pub fn extract_sensitive_data(source_code: &str) -> Vec<SourceLeakFinding>Available on crate feature
react2shell only.Expand description
Extract sensitive data from leaked source code using regex patterns.
pub fn extract_sensitive_data(source_code: &str) -> Vec<SourceLeakFinding>react2shell only.Extract sensitive data from leaked source code using regex patterns.