pub fn print_scan_result(result: &ScanResult)Available on crate feature
react2shell only.Expand description
Print a scan result to the console with ANSI colors.
pub fn print_scan_result(result: &ScanResult)react2shell only.Print a scan result to the console with ANSI colors.