pub async fn scan_and_report(
target: &str,
verbose: bool,
) -> Result<AttackReport>Available on crate feature
react2shell only.Expand description
Run a full vulnerability scan and generate a console report.
pub async fn scan_and_report(
target: &str,
verbose: bool,
) -> Result<AttackReport>react2shell only.Run a full vulnerability scan and generate a console report.